@@ -1061,7 +1061,7 @@ class VariableClInstallFs(Variable):
     """
     type = "list"
 
-    value = ["ext4", "btrfs", "reiserfs", "ext3"]
+    value = ["btrfs", "ext4", "reiserfs", "ext3"]
 
 class FlashUncompatible(VariableInterface):
     def uncompatible(self):
